// 间隔多长时间取一个采样点
// duration 秒，有小数点
const sampleInterval = (duration) => {
    let interval = (duration > 20 * 60) ? 200 : 100;
    let isFirefox = window.navigator.userAgent.includes("Firefox");
    if (isFirefox && (interval < 400)) interval = 400; // firefox canvas width 不能过长
    return interval;
}

// interval 间隔ms采点
function audioWaveData(url, interval) {
    if (url.length <= 0) return;
    console.log("audioWaveData", url, interval);
    return fetch(url)
        .then(response => response.blob())
        .then(blob => blob.arrayBuffer())
        .then(arrayBuffer => {
            let context = new (window.AudioContext || window.webkitAudioContext)();
            return context.decodeAudioData(arrayBuffer).then(audioBuffer => {
                let pointsInterval = audioBuffer.sampleRate / 1000 * interval;
                let waveData = audioBuffer.getChannelData(0);
                let wave = [];
                let amplitude = 0;
                for (let i = 0; i < waveData.length; i++) {
                    amplitude += Math.abs(waveData[i]);
                    if (i % pointsInterval == 0) {
                        wave.push(Math.floor(amplitude * 500 / pointsInterval));
                        amplitude = 0;
                    }
                }
                return wave;
            })
        });
}

function validatePhoneNumber(phoneNumber) {
    if (phoneNumber.length !== 11) {
        return false;
    }
    let reg = /^1\d{10}$/;
    return reg.test(phoneNumber);
}

function textHintOfValidatePhoneNumber(phoneNumber) {
    if (validatePhoneNumber(phoneNumber)) return "";
    if (phoneNumber.length === 0) return "请输入手机号码"
    return "请输入正确的手机号码";
}

export { sampleInterval, audioWaveData, validatePhoneNumber, textHintOfValidatePhoneNumber };